r3812 jshaw - /trunk/netsurfbuild/svnlog2html.xslt
by netsurf@semichrome.net
Author: jshaw
Date: Thu Jan 31 21:02:34 2008
New Revision: 3812
URL: http://source.netsurf-browser.org?rev=3812&view=rev
Log:
Implement partial path display
Modified:
trunk/netsurfbuild/svnlog2html.xslt
Modified: trunk/netsurfbuild/svnlog2html.xslt
URL: http://source.netsurf-browser.org/trunk/netsurfbuild/svnlog2html.xslt?rev...
==============================================================================
--- trunk/netsurfbuild/svnlog2html.xslt (original)
+++ trunk/netsurfbuild/svnlog2html.xslt Thu Jan 31 21:02:34 2008
@@ -1,5 +1,9 @@
<?xml version="1.0"?>
-<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
+<xsl:stylesheet
+ xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
+ xmlns:str="http://exslt.org/strings"
+ version="1.0"
+ extension-element-prefixes="str">
<xsl:output method="html" encoding="iso-8859-1" media-type="text/html"/>
<xsl:template match="log">
@@ -23,6 +27,14 @@
<xsl:text>r</xsl:text>
<xsl:value-of select="@revision"/>
</a>
+ <xsl:text> - </xsl:text>
+ <span class="svnpath">
+ <xsl:text>(in </xsl:text>
+ <xsl:call-template name="truncate-path">
+ <xsl:with-param name="path" select="paths/path[1]/text()"/>
+ </xsl:call-template>
+ <xsl:text>)</xsl:text>
+ </span>
</p>
<p class="msg">
<xsl:value-of select="msg"/>
@@ -32,5 +44,14 @@
</div>
</xsl:template>
+ <xsl:template name="truncate-path">
+ <xsl:param name="path"/>
+ <xsl:variable name="tokens" select="str:tokenize($path, '/')"/>
+ <xsl:value-of select="concat($tokens[1], '/', $tokens[2])"/>
+ <xsl:if test="$tokens[1] != 'trunk'">
+ <xsl:value-of select="concat('/', $tokens[3])"/>
+ </xsl:if>
+ </xsl:template>
+
</xsl:stylesheet>
15 years, 1 month
r3811 jmb - /trunk/netsurf/css/css.c
by netsurf@semichrome.net
Author: jmb
Date: Thu Jan 31 01:47:57 2008
New Revision: 3811
URL: http://source.netsurf-browser.org?rev=3811&view=rev
Log:
Add function to dump working stylesheets
Modified:
trunk/netsurf/css/css.c
Modified: trunk/netsurf/css/css.c
URL: http://source.netsurf-browser.org/trunk/netsurf/css/css.c?rev=3811&r1=381...
==============================================================================
--- trunk/netsurf/css/css.c (original)
+++ trunk/netsurf/css/css.c Thu Jan 31 01:47:57 2008
@@ -130,6 +130,8 @@
xmlNode *element);
static void css_dump_length(const struct css_length * const length);
static void css_dump_selector(const struct css_selector *r);
+static void css_dump_working_stylesheet(
+ const struct css_working_stylesheet *ws);
/** Default style for a document. These are the 'Initial values' from the
* spec. */
@@ -1012,6 +1014,8 @@
talloc_free(rule_scratch);
+ /*css_dump_working_stylesheet(working_stylesheet);*/
+
return working_stylesheet;
}
@@ -2403,6 +2407,24 @@
css_unit_name[length->unit]);
}
+/**
+ * Dump a complete css_working_stylesheet to stderr in CSS syntax.
+ */
+
+void css_dump_working_stylesheet(const struct css_working_stylesheet *ws)
+{
+ unsigned int i, j;
+
+ for (i = 0; i != HASH_SIZE; i++) {
+ /*fprintf(stderr, "hash %i:\n", i);*/
+ for (j = 0; ws->rule[i][j]; j++) {
+ css_dump_selector(ws->rule[i][j]);
+ fprintf(stderr, " <%lx> ", ws->rule[i][j]->specificity);
+ css_dump_style(ws->rule[i][j]->style);
+ fprintf(stderr, "\n");
+ }
+ }
+}
/**
* Dump a complete css_stylesheet to stderr in CSS syntax.
15 years, 1 month
r3810 tlsa - /trunk/netsurf/!NetSurf/Resources/CSS,f79
by netsurf@semichrome.net
Author: tlsa
Date: Wed Jan 30 22:09:41 2008
New Revision: 3810
URL: http://source.netsurf-browser.org?rev=3810&view=rev
Log:
Revert last change because it made the tracker almost unusable.
Modified:
trunk/netsurf/!NetSurf/Resources/CSS,f79
Modified: trunk/netsurf/!NetSurf/Resources/CSS,f79
URL: http://source.netsurf-browser.org/trunk/netsurf/%21NetSurf/Resources/CSS%...
==============================================================================
--- trunk/netsurf/!NetSurf/Resources/CSS,f79 (original)
+++ trunk/netsurf/!NetSurf/Resources/CSS,f79 Wed Jan 30 22:09:41 2008
@@ -39,10 +39,8 @@
q { font-style: italic; }
-/* sub { vertical-align: sub; font-size: .83em; } */
-/* sup { vertical-align: super; font-size: .83em; } */
-sub { position: relative; top: 0.5em; font-size: .83em; }
-sup { position: relative; bottom: 0.2em; font-size: .83em; }
+sub { vertical-align: sub; font-size: .83em; }
+sup { vertical-align: super; font-size: .83em; }
p { display: block; margin: 1.12em 0; }
15 years, 1 month
r3809 jmb - in /trunk/netsurf/content: fetch.c fetch.h fetchcache.c fetchers/fetch_curl.c
by netsurf@semichrome.net
Author: jmb
Date: Wed Jan 30 19:56:41 2008
New Revision: 3809
URL: http://source.netsurf-browser.org?rev=3809&view=rev
Log:
Make core fetching code handle verifiability of transactions
Make core fetching code be responsible for inserting cookies into the urldb
Provide accessor to a fetch's parent url (this is defined as being the URL of the verifiable fetch which caused this one to occur)
Make fetchcache's 3xx handling use the parent url when spawning new fetches
Modified:
trunk/netsurf/content/fetch.c
trunk/netsurf/content/fetch.h
trunk/netsurf/content/fetchcache.c
trunk/netsurf/content/fetchers/fetch_curl.c
Modified: trunk/netsurf/content/fetch.c
URL: http://source.netsurf-browser.org/trunk/netsurf/content/fetch.c?rev=3809&...
==============================================================================
--- trunk/netsurf/content/fetch.c (original)
+++ trunk/netsurf/content/fetch.c Wed Jan 30 19:56:41 2008
@@ -81,6 +81,8 @@
char *url; /**< URL. */
char *referer; /**< Referer URL. */
bool send_referer; /**< Valid to send the referer */
+ bool verifiable; /**< Transaction is verifiable */
+ char *parent_fetch_url; /**< URL of parent fetch */
void *p; /**< Private data for callback. */
char *host; /**< Host part of URL. */
long http_code; /**< HTTP response code, or 0. */
@@ -266,6 +268,8 @@
fetch->abort = false;
fetch->stopped = false;
fetch->url = strdup(url);
+ fetch->verifiable = verifiable;
+ fetch->parent_fetch_url = parent_url ? strdup(parent_url) : 0;
fetch->p = p;
fetch->host = host;
fetch->http_code = 0;
@@ -286,7 +290,8 @@
fetch->send_referer = true;
}
- if (!fetch->url)
+ if (!fetch->url ||
+ (parent_url && !fetch->parent_fetch_url))
goto failed;
/* Pick the scheme ops */
@@ -304,8 +309,7 @@
/* Got a scheme fetcher, try and set up the fetch */
fetch->fetcher_handle =
fetch->ops->setup_fetch(fetch, url, only_2xx, post_urlenc,
- post_multipart, verifiable, parent_url,
- (const char **)headers);
+ post_multipart, (const char **)headers);
if (fetch->fetcher_handle == NULL)
goto failed;
@@ -333,6 +337,7 @@
free(host);
if (ref1)
free(ref1);
+ free(fetch->parent_fetch_url);
free(fetch->url);
if (fetch->referer)
free(fetch->referer);
@@ -454,6 +459,7 @@
LOG(("Freeing fetch %p, fetcher %p", f, f->fetcher_handle));
f->ops->free_fetch(f->fetcher_handle);
fetch_unref_fetcher(f->ops);
+ free(f->parent_fetch_url);
free(f->url);
free(f->host);
if (f->referer)
@@ -549,6 +555,20 @@
return fetch->referer;
}
+/**
+ * Get the parent URL for this fetch
+ *
+ * \param fetch fetch to retrieve parent url from
+ * \return Pointer to parent url, or NULL if none.
+ */
+const char *fetch_get_parent_url(struct fetch *fetch)
+{
+ assert(fetch);
+
+ /* If the fetch is verifiable, then its own URL suffices */
+ return fetch->verifiable ? fetch->url : fetch->parent_fetch_url;
+}
+
void
fetch_send_callback(fetch_msg msg, struct fetch *fetch, const void *data,
unsigned long size)
@@ -596,3 +616,22 @@
return fetch->referer;
return NULL;
}
+
+void
+fetch_set_cookie(struct fetch *fetch, const char *data)
+{
+ assert(fetch && data);
+
+ /* If the fetch is unverifiable and there's no parent fetch
+ * url, err on the side of caution and do not set the cookie */
+
+ if (fetch->verifiable || fetch->parent_fetch_url) {
+ /* If the transaction's verifiable, we don't require
+ * that the request uri and the parent domain match,
+ * so don't pass in the parent in this case. */
+ urldb_set_cookie(data, fetch->url,
+ fetch->verifiable ? 0
+ : fetch->parent_fetch_url);
+ }
+}
+
Modified: trunk/netsurf/content/fetch.h
URL: http://source.netsurf-browser.org/trunk/netsurf/content/fetch.h?rev=3809&...
==============================================================================
--- trunk/netsurf/content/fetch.h (original)
+++ trunk/netsurf/content/fetch.h Wed Jan 30 19:56:41 2008
@@ -96,14 +96,15 @@
void *p);
long fetch_http_code(struct fetch *fetch);
const char *fetch_get_referer(struct fetch *fetch);
+const char *fetch_get_parent_url(struct fetch *fetch);
/* API for fetchers themselves */
typedef bool (*fetcher_initialise)(const char *);
typedef void* (*fetcher_setup_fetch)(struct fetch *, const char *,
bool, const char *,
- struct form_successful_control *, bool,
- const char *, const char **);
+ struct form_successful_control *,
+ const char **);
typedef bool (*fetcher_start_fetch)(void *);
typedef void (*fetcher_abort_fetch)(void *);
typedef void (*fetcher_free_fetch)(void *);
@@ -125,4 +126,5 @@
void fetch_free(struct fetch *f);
void fetch_set_http_code(struct fetch *fetch, long http_code);
const char *fetch_get_referer_to_send(struct fetch *fetch);
+void fetch_set_cookie(struct fetch *fetch, const char *data);
#endif
Modified: trunk/netsurf/content/fetchcache.c
URL: http://source.netsurf-browser.org/trunk/netsurf/content/fetchcache.c?rev=...
==============================================================================
--- trunk/netsurf/content/fetchers/fetch_curl.c (original)
+++ trunk/netsurf/content/fetchers/fetch_curl.c Wed Jan 30 19:56:41 2008
@@ -74,11 +74,8 @@
bool abort; /**< Abort requested. */
bool stopped; /**< Download stopped on purpose. */
bool only_2xx; /**< Only HTTP 2xx responses acceptable. */
- bool verifiable; /**< Transaction is verifiable */
char *url; /**< URL of this fetch. */
char *host; /**< The hostname of this fetch. */
- char *parent_fetch_url; /**< URL of parent fetch (not necessarily
- * the same as the referer) */
struct curl_slist *headers; /**< List of request headers. */
char *location; /**< Response Location header, or 0. */
unsigned long content_length; /**< Response Content-Length, or 0. */
@@ -119,7 +116,7 @@
static void * fetch_curl_setup(struct fetch *parent_fetch, const char *url,
bool only_2xx, const char *post_urlenc,
struct form_successful_control *post_multipart,
- bool verifiable, const char *parent_url, const char **headers);
+ const char **headers);
static bool fetch_curl_start(void *vfetch);
static bool fetch_curl_initiate_fetch(struct curl_fetch_info *fetch,
CURL *handle);
@@ -299,7 +296,7 @@
void * fetch_curl_setup(struct fetch *parent_fetch, const char *url,
bool only_2xx, const char *post_urlenc,
struct form_successful_control *post_multipart,
- bool verifiable, const char *parent_url, const char **headers)
+ const char **headers)
{
char *host;
struct curl_fetch_info *fetch;
@@ -332,9 +329,7 @@
fetch->abort = false;
fetch->stopped = false;
fetch->only_2xx = only_2xx;
- fetch->verifiable = verifiable;
fetch->url = strdup(url);
- fetch->parent_fetch_url = parent_url ? strdup(parent_url) : 0;
fetch->headers = 0;
fetch->host = host;
fetch->location = 0;
@@ -365,7 +360,6 @@
#endif
if (!fetch->url ||
- (parent_url && !fetch->parent_fetch_url) ||
(post_urlenc && !fetch->post_urlenc) ||
(post_multipart && !fetch->post_multipart))
goto failed;
@@ -423,7 +417,6 @@
failed:
free(host);
free(fetch->url);
- free(fetch->parent_fetch_url);
free(fetch->post_urlenc);
if (fetch->post_multipart)
curl_formfree(fetch->post_multipart);
@@ -703,7 +696,6 @@
curl_easy_cleanup(f->curl_handle);
free(f->url);
free(f->host);
- free(f->parent_fetch_url);
free(f->location);
free(f->cookie_string);
free(f->realm);
@@ -1158,18 +1150,7 @@
/* extract Set-Cookie header */
SKIP_ST(11);
- /* If the fetch is unverifiable and there's no parent fetch
- * url, err on the side of caution and do not set the
- cookie */
-
- if (f->verifiable || f->parent_fetch_url) {
- /* If the transaction's verifiable, we don't require
- * that the request uri and the parent domain match,
- * so don't pass in the parent in this case. */
- urldb_set_cookie(&data[i], f->url,
- f->verifiable ? 0
- : f->parent_fetch_url);
- }
+ fetch_set_cookie(f->fetch_handle, &data[i]);
}
return size;
15 years, 1 month
r3808 tlsa - /trunk/netsurf/!NetSurf/Resources/CSS,f79
by netsurf@semichrome.net
Author: tlsa
Date: Wed Jan 30 18:30:59 2008
New Revision: 3808
URL: http://source.netsurf-browser.org?rev=3808&view=rev
Log:
Support SUP and SUB tags with relative position in default CSS file.
Modified:
trunk/netsurf/!NetSurf/Resources/CSS,f79
Modified: trunk/netsurf/!NetSurf/Resources/CSS,f79
URL: http://source.netsurf-browser.org/trunk/netsurf/%21NetSurf/Resources/CSS%...
==============================================================================
--- trunk/netsurf/!NetSurf/Resources/CSS,f79 (original)
+++ trunk/netsurf/!NetSurf/Resources/CSS,f79 Wed Jan 30 18:30:59 2008
@@ -39,8 +39,10 @@
q { font-style: italic; }
-sub { vertical-align: sub; font-size: .83em; }
-sup { vertical-align: super; font-size: .83em; }
+/* sub { vertical-align: sub; font-size: .83em; } */
+/* sup { vertical-align: super; font-size: .83em; } */
+sub { position: relative; top: 0.5em; font-size: .83em; }
+sup { position: relative; bottom: 0.2em; font-size: .83em; }
p { display: block; margin: 1.12em 0; }
15 years, 1 month
r3807 jmb - in /trunk/netsurf/content: fetchcache.c urldb.c
by netsurf@semichrome.net
Author: jmb
Date: Wed Jan 30 01:44:57 2008
New Revision: 3807
URL: http://source.netsurf-browser.org?rev=3807&view=rev
Log:
Ensure plq is terminated when looking for an URL path.
Ensure fetchcache_redirect() normalizes the redirect destination.
Modified:
trunk/netsurf/content/fetchcache.c
trunk/netsurf/content/urldb.c
Modified: trunk/netsurf/content/fetchcache.c
URL: http://source.netsurf-browser.org/trunk/netsurf/content/fetchcache.c?rev=...
==============================================================================
--- trunk/netsurf/content/fetchcache.c (original)
+++ trunk/netsurf/content/fetchcache.c Wed Jan 30 01:44:57 2008
@@ -768,7 +768,7 @@
void fetchcache_redirect(struct content *c, const void *data,
unsigned long size)
{
- char *url;
+ char *url, *url1;
char *referer;
long http_code = fetch_http_code(c->fetch);
const char *ref = fetch_get_referer(c->fetch);
@@ -843,8 +843,7 @@
/* redirect URLs must be absolute by HTTP/1.1, but many
* sites send relative ones: treat them as relative to
* requested URL */
- result = url_join(data, c->url, &url);
-
+ result = url_join(data, c->url, &url1);
if (result != URL_FUNC_OK) {
msg_data.error = messages_get("BadRedirect");
content_broadcast(c, CONTENT_MSG_ERROR, msg_data);
@@ -852,6 +851,21 @@
free(referer);
return;
}
+
+ /* Normalize redirect target -- this is vital as this URL may
+ * be inserted into the urldb, which expects normalized URLs */
+ result = url_normalize(url1, &url);
+ if (result != URL_FUNC_OK) {
+ msg_data.error = messages_get("BadRedirect");
+ content_broadcast(c, CONTENT_MSG_ERROR, msg_data);
+
+ free(url1);
+ free(referer);
+ return;
+ }
+
+ /* No longer need url1 */
+ free(url1);
/* Process users of this content */
while (c->user_list->next) {
Modified: trunk/netsurf/content/urldb.c
URL: http://source.netsurf-browser.org/trunk/netsurf/content/urldb.c?rev=3807&...
==============================================================================
--- trunk/netsurf/content/urldb.c (original)
+++ trunk/netsurf/content/urldb.c Wed Jan 30 01:44:57 2008
@@ -1826,6 +1826,9 @@
url_destroy_components(&components);
return NULL;
}
+
+ /* Ensure plq is terminated */
+ *plq = '\0';
copy = plq;
if (components.path) {
15 years, 1 month
r3806 tlsa - /trunk/netsurftest/haveproblems/background-edge.html
by netsurf@semichrome.net
Author: tlsa
Date: Tue Jan 29 23:44:16 2008
New Revision: 3806
URL: http://source.netsurf-browser.org?rev=3806&view=rev
Log:
More complete range of tests.
Modified:
trunk/netsurftest/haveproblems/background-edge.html
Modified: trunk/netsurftest/haveproblems/background-edge.html
URL: http://source.netsurf-browser.org/trunk/netsurftest/haveproblems/backgrou...
==============================================================================
--- trunk/netsurftest/haveproblems/background-edge.html (original)
+++ trunk/netsurftest/haveproblems/background-edge.html Tue Jan 29 23:44:16 2008
@@ -27,6 +27,12 @@
<p style="background:#faa url(../images/3x3.png) repeat-x top left;border:10px solid transparent;">
<span>bg colour + bg image (top left repeat-x) + transparent border</span>
</p>
+<p style="background:#faa url(../images/3x3.png) repeat-x center left;border:10px solid transparent;">
+<span>bg colour + bg image (center left repeat-x) + transparent border</span>
+</p>
+<p style="background:#faa url(../images/3x3.png) repeat-x bottom left;border:10px solid transparent;">
+<span>bg colour + bg image (bottom left repeat-x) + transparent border</span>
+</p>
<p style="background:#faa url(../images/3x3.png) repeat-x top left;border:10px solid #afa;">
<span>bg colour + bg image (top left repeat-x) + coloured border</span>
</p>
@@ -39,8 +45,14 @@
<p style="background:url(../images/3x3.png) repeat-y bottom right;border:10px solid transparent;">
<span>bg image (bottom right repeat-y) + transparent border</span>
</p>
+<p style="background:#faa url(../images/3x3.png) repeat-y bottom left;border:10px solid transparent;">
+<span>bg image (bottom left repeat-y) + transparent border</span>
+</p>
+<p style="background:#faa url(../images/3x3.png) repeat-y bottom center;border:10px solid transparent;">
+<span>bg image (bottom center repeat-y) + transparent border</span>
+</p>
<p style="background:#faa url(../images/3x3.png) repeat-y bottom right;border:10px solid transparent;">
-<span>bg image (bottom right repeat-y) + transparent border</span>
+<span>bg image (top right repeat-y) + transparent border</span>
</p>
</body>
15 years, 1 month
r3805 tlsa - /trunk/netsurf/gtk/gtk_options.c
by netsurf@semichrome.net
Author: tlsa
Date: Tue Jan 29 20:46:10 2008
New Revision: 3805
URL: http://source.netsurf-browser.org?rev=3805&view=rev
Log:
Stop min gif delay option growing every time choices are saved on nsgtk. Use same scale factor as RISC OS.
Modified:
trunk/netsurf/gtk/gtk_options.c
Modified: trunk/netsurf/gtk/gtk_options.c
URL: http://source.netsurf-browser.org/trunk/netsurf/gtk/gtk_options.c?rev=380...
==============================================================================
--- trunk/netsurf/gtk/gtk_options.c (original)
+++ trunk/netsurf/gtk/gtk_options.c Tue Jan 29 20:46:10 2008
@@ -161,7 +161,7 @@
SET_CHECK(checkUseCairo, option_render_cairo);
SET_CHECK(checkResampleImages, option_render_resample);
- SET_SPIN(spinAnimationSpeed, option_minimum_gif_delay);
+ SET_SPIN(spinAnimationSpeed, option_minimum_gif_delay / 100);
SET_CHECK(checkDisableAnimations, !option_animate_images);
SET_FONT(fontSansSerif, option_font_sans);
@@ -232,7 +232,7 @@
GET_CHECK(checkUseCairo, option_render_cairo);
GET_CHECK(checkResampleImages, option_render_resample);
GET_SPIN(spinAnimationSpeed, option_minimum_gif_delay);
- option_minimum_gif_delay *= 10;
+ option_minimum_gif_delay *= 100;
GET_FONT(fontSansSerif, option_font_sans);
GET_FONT(fontSerif, option_font_serif);
15 years, 1 month
r3804 tlsa - /trunk/netsurftest/haveproblems/star-selector.html
by netsurf@semichrome.net
Author: tlsa
Date: Tue Jan 29 18:41:40 2008
New Revision: 3804
URL: http://source.netsurf-browser.org?rev=3804&view=rev
Log:
Test case for specificity problem by Bart Nagel.
Added:
trunk/netsurftest/haveproblems/star-selector.html
Added: trunk/netsurftest/haveproblems/star-selector.html
URL: http://source.netsurf-browser.org/trunk/netsurftest/haveproblems/star-sel...
==============================================================================
--- trunk/netsurftest/haveproblems/star-selector.html (added)
+++ trunk/netsurftest/haveproblems/star-selector.html Tue Jan 29 18:41:40 2008
@@ -1,0 +1,28 @@
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
+<html>
+<head>
+ <title>star selector not being overridden</title>
+ <style type="text/css">
+ * {
+ background-color: yellow;
+ }
+ p {
+ background-color: red;
+ }
+ </style>
+</head>
+<body>
+
+<p>This paragraph text should have a red background.</p>
+
+<pre>
+* {
+ background-color: yellow;
+}
+p {
+ background-color: red;
+}
+</pre>
+
+</body>
+</html>
15 years, 1 month
r3803 tlsa - in /trunk/netsurfweb/downloads/themes: Steel.theme Steeli.png index.en
by netsurf@semichrome.net
Author: tlsa
Date: Tue Jan 29 16:00:43 2008
New Revision: 3803
URL: http://source.netsurf-browser.org?rev=3803&view=rev
Log:
Add Steel theme by Chris Wraight.
Added:
trunk/netsurfweb/downloads/themes/Steel.theme (with props)
trunk/netsurfweb/downloads/themes/Steeli.png (with props)
Modified:
trunk/netsurfweb/downloads/themes/index.en
Added: trunk/netsurfweb/downloads/themes/Steel.theme
URL: http://source.netsurf-browser.org/trunk/netsurfweb/downloads/themes/Steel...
==============================================================================
Binary file - no diff available.
Propchange: trunk/netsurfweb/downloads/themes/Steel.theme
------------------------------------------------------------------------------
svn:mime-type = application/octet-stream
Added: trunk/netsurfweb/downloads/themes/Steeli.png
URL: http://source.netsurf-browser.org/trunk/netsurfweb/downloads/themes/Steel...
==============================================================================
Binary file - no diff available.
Propchange: trunk/netsurfweb/downloads/themes/Steeli.png
------------------------------------------------------------------------------
svn:mime-type = application/octet-stream
Modified: trunk/netsurfweb/downloads/themes/index.en
URL: http://source.netsurf-browser.org/trunk/netsurfweb/downloads/themes/index...
==============================================================================
--- trunk/netsurfweb/downloads/themes/index.en (original)
+++ trunk/netsurfweb/downloads/themes/index.en Tue Jan 29 16:00:43 2008
@@ -80,6 +80,11 @@
<p class="themeimage"><a href="RO5"><img src="RO5i.png" alt="Install theme"></a></p>
<p class="themeauthor">Author: <a href="http://hallas.net/">Richard G. Hallas</a></p>
+<h2 class="themename">Steel</h2>
+
+<p class="themeimage"><a href="Steel"><img src="Steeli.png" alt="Install theme"></a></p>
+<p class="themeauthor">Author: <a href="http://lym.iconbar.com/">Chris Wraight</a></p>
+
<div class="footer">
<p>Copyright 2003 - 2008 The NetSurf Developers</p>
</div>
15 years, 1 month
--- trunk/netsurf/content/fetchcache.c (original)
+++ trunk/netsurf/content/fetchcache.c Wed Jan 30 19:56:41 2008
@@ -730,7 +730,9 @@
/* No cached content, so unconditionally refetch */
struct content_user *u;
const char *ref = fetch_get_referer(c->fetch);
+ const char *parent = fetch_get_parent_url(c->fetch);
char *referer = NULL;
+ char *parent_url = NULL;
if (ref) {
referer = strdup(ref);
@@ -744,6 +746,19 @@
}
}
+ if (parent) {
+ parent_url = strdup(parent);
+ if (!parent_url) {
+ c->type = CONTENT_UNKNOWN;
+ c->status = CONTENT_STATUS_ERROR;
+ msg_data.error = messages_get("NoMemory");
+ content_broadcast(c, CONTENT_MSG_ERROR,
+ msg_data);
+ free(referer);
+ return;
+ }
+ }
+
fetch_abort(c->fetch);
c->fetch = 0;
@@ -754,9 +769,10 @@
for (u = c->user_list->next; u; u = u->next) {
fetchcache_go(c, referer, u->callback, u->p1, u->p2,
c->width, c->height, 0, 0,
- false, ref ? referer : c->url);
- }
-
+ false, parent_url);
+ }
+
+ free(parent_url);
free(referer);
}
}
@@ -769,9 +785,10 @@
unsigned long size)
{
char *url, *url1;
- char *referer;
+ char *referer, *parent_url;
long http_code = fetch_http_code(c->fetch);
const char *ref = fetch_get_referer(c->fetch);
+ const char *parent = fetch_get_parent_url(c->fetch);
union content_msg_data msg_data;
url_func_result result;
@@ -783,8 +800,15 @@
/* 304 is handled by fetch_notmodified() */
assert(http_code != 304);
- /* Clone referer -- original is destroyed in fetch_abort() */
+ /* Extract fetch details */
+ http_code = fetch_http_code(c->fetch);
+ ref = fetch_get_referer(c->fetch);
+ parent = fetch_get_parent_url(c->fetch);
+
+ /* Clone referer and parent url
+ * originals are destroyed in fetch_abort() */
referer = ref ? strdup(ref) : NULL;
+ parent_url = parent ? strdup(parent) : NULL;
/* set the status to ERROR so that this content is
* destroyed in content_clean() */
@@ -800,6 +824,18 @@
msg_data.error = messages_get("BadRedirect");
content_broadcast(c, CONTENT_MSG_ERROR, msg_data);
+ return;
+ }
+
+ /* Ensure parent url cloning succeeded
+ * _must_ be after content invalidation */
+ if (parent && !parent_url) {
+ LOG(("Failed cloning parent url"));
+
+ msg_data.error = messages_get("BadRedirect");
+ content_broadcast(c, CONTENT_MSG_ERROR, msg_data);
+
+ free(referer);
return;
}
@@ -823,6 +859,7 @@
msg_data.error = messages_get("BadRedirect");
content_broadcast(c, CONTENT_MSG_ERROR, msg_data);
+ free(parent_url);
free(referer);
return;
}
@@ -835,6 +872,7 @@
msg_data.error = messages_get("BadRedirect");
content_broadcast(c, CONTENT_MSG_ERROR, msg_data);
+ free(parent_url);
free(referer);
return;
}
@@ -848,6 +886,7 @@
msg_data.error = messages_get("BadRedirect");
content_broadcast(c, CONTENT_MSG_ERROR, msg_data);
+ free(parent_url);
free(referer);
return;
}
@@ -860,6 +899,7 @@
content_broadcast(c, CONTENT_MSG_ERROR, msg_data);
free(url1);
+ free(parent_url);
free(referer);
return;
}
@@ -892,6 +932,7 @@
content_broadcast(c, CONTENT_MSG_ERROR, msg_data);
free(url);
+ free(parent_url);
free(referer);
return;
}
@@ -905,11 +946,12 @@
/* Start fetching the replacement content */
fetchcache_go(replacement, referer, callback, p1, p2,
c->width, c->height, NULL, NULL,
- false, referer ? referer : c->url);
+ false, parent_url);
}
/* Clean up */
free(url);
+ free(parent_url);
free(referer);
}
Modified: trunk/netsurf/content/fetchers/fetch_curl.c
URL: http://source.netsurf-browser.org/trunk/netsurf/content/fetchers/fetch_cu...
==============================================================================